@@ -1,5 +1,5 @@
 package Finance::AMEX::Transaction::GRRCN::Submission;
-$Finance::AMEX::Transaction::GRRCN::Submission::VERSION = '0.003';
+$Finance::AMEX::Transaction::GRRCN::Submission::VERSION = '0.004';
 use strict;
 use warnings;
 
@@ -8,6 +8,8 @@ use warnings;
 use base 'Finance::AMEX::Transaction::GRRCN::Base';
 
 sub field_map {
+  my ($self) = @_;
+
   return {
     RECORD_TYPE                                    => [1, 10],
     PAYEE_MERCHANT_ID                              => [11, 15],
@@ -21,6 +23,13 @@ sub field_map {
     AMERICAN_EXPRESS_PROCESSING_DATE               => [73, 18],
     SUBMISSION_INVOICE_NUMBER                      => [81, 15],
     SUBMISSION_CURRENCY                            => [96, 3],
+
+    (
+      $self->version >= 2.01
+      ? ( FILLER => [99, 15] )
+      : ()
+    ),
+
     SUBMISSION_EXCHANGE_RATE                       => [114, 15],
     SUBMISSION_GROSS_AMOUNT_IN_SUBMISSION_CURRENCY => [129, 15],
     SUBMISSION_GROSS_AMOUNT_IN_PAYMENT_CURRENCY    => [145, 16],
@@ -51,6 +60,7 @@ sub PAYEE_MERCHANT_ID                              {return $_[0]->_get_column('P
 sub SETTLEMENT_ACCOUNT_TYPE_CODE                   {return $_[0]->_get_column('SETTLEMENT_ACCOUNT_TYPE_CODE')}
 sub AMERICAN_EXPRESS_PAYMENT_NUMBER                {return $_[0]->_get_column('AMERICAN_EXPRESS_PAYMENT_NUMBER')}
 sub PAYMENT_DATE                                   {return $_[0]->_get_column('PAYMENT_DATE')}
+sub FILLER                                         {return $_[0]->_get_column('FILLER')}
 
 sub PAYMENT_CURRENCY                               {return $_[0]->_get_column('PAYMENT_CURRENCY')}
 sub SUBMISSION_MERCHANT_ID                         {return $_[0]->_get_column('SUBMISSION_MERCHANT_ID')}
@@ -93,7 +103,7 @@ Finance::AMEX::Transaction::GRRCN::Submission - Parse AMEX Global Reconciliation
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -435,11 +445,11 @@ Finance::AMEX::Transaction::GRRCN::Submission - Object methods for AMEX Global R
 
 =head1 AUTHOR
 
-Tom Heady <theady@ziprecruiter.com>
+Tom Heady <cpan@punch.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by ZipRecruiter.
+This software is copyright (c) 2021 by ZipRecruiter.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
